import React, { useState } from 'react';
import { View, Image, TextInput, TouchableOpacity, StyleSheet, Alert, Text } from 'react-native';
import * as ImagePicker from 'expo-image-picker';
import Modal from '../Modal';
import Input from '../Input';

import PlusSVG from '../../../assets/icons/plus.svg';
import TrashSVG from '../../../assets/icons/trash.svg';

interface AddPhotoProps {
  initialImagePath?: string | null;
  initialImageDescription?: string;
  onImagePicked?: (uri: string) => void;
  onImageDeleted?: () => void;
  closeModal: () => void;
}

const AddPhoto: React.FC<AddPhotoProps> = ({ initialImagePath, initialImageDescription, onImagePicked, onImageDeleted, closeModal }) => {
  const [image, setImage] = useState(initialImagePath);
  const [description, setDescription] = useState(initialImageDescription ?? '');

  const handleDelete = () => {
    Alert.alert('Delete Image', 'Are you sure you want to delete this image?', [
      { text: 'Cancel' },
      { text: 'Delete', onPress: () => {
        setImage(null);
        // onImageDeleted();
      }},
    ]);
  };

  const handleImagePick = async () => {
    const { status } = await ImagePicker.requestMediaLibraryPermissionsAsync();
    if (status !== 'granted') {
      Alert.alert('Permission Denied', 'Sorry, we need media library permissions to make this work!');
      return;
    }

    let result = await ImagePicker.launchImageLibraryAsync({
      mediaTypes: ImagePicker.MediaTypeOptions.Images,
      // aspect: [4, 3],
      quality: 1,
    });

    if (!result.canceled) {
      setImage(result.assets[0].uri);
      // onImagePicked(result.uri);
    }
  };

  return (
    <Modal
      visible={true}
      onRequestClose={closeModal}
      textHeader='Add Photo'
    >
      <View style={styles.container}>
        <View style={styles.imageContainer}>
          {image ? (
            <>
              <TouchableOpacity onPress={handleDelete} style={styles.deleteButton}>
                <View style={[styles.addButton, {width: 40, height: 40, backgroundColor: '#EF5B5B', borderRadius: 20}]}>
                  <TrashSVG />
                </View>
              </TouchableOpacity>
              <Image source={{ uri: image }} style={styles.image} />
            </>
          ) : (
            <TouchableOpacity onPress={handleImagePick} style={styles.addButton}>
              <View style={[styles.addButton, {width: 48, height: 48, backgroundColor: '#0F3F4F', borderRadius: 24}]}>
                <PlusSVG />
              </View>
              
              <Text style={styles.addButtonText}>Upload Photo</Text>
            </TouchableOpacity>
          )}
        </View>
        <View style={styles.description}>
          <Input
            header='Description'
            placeholder="Add photo description here"
            onChange={setDescription}
          />
        </View>
      </View>
    </Modal>
  );
};

const styles = StyleSheet.create({
  container: {
    alignItems: 'center',
    justifyContent: 'center',
    padding: 24,
  },
  imageContainer: {
    position: 'relative',
    marginBottom: 8,
    width: '100%',
    height: 327,
    alignItems: 'center',
    justifyContent: 'center',
    borderRadius: 8,
    backgroundColor: '#FAFAFA'
  },
  deleteButton: {
    position: 'absolute',
    top: 16,
    right: 16,
    zIndex: 1,
  },
  image: {
    width: '100%',
    height: '100%',
    resizeMode: 'cover',
    borderRadius: 8,
  },
  description: {
    width: '100%',
    marginTop: 8,
  },
  addButton: {
    justifyContent: 'center',
    alignItems: 'center',
  },
  addButtonText: {
    fontSize: 16,
    marginTop: 10,
    fontWeight: '700',
    color: '#0F3F4F',
    lineHeight: 24,
  },
});

export default AddPhoto;
